#
# spec file for package klog
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           klog
Version:        6.5
Release:        1.2
Summary:        Time tracking in a human-readable, plain-text file format
License:        MIT
URL:            https://github.com/jotaen/klog
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  bash-completion
BuildRequires:  fish
BuildRequires:  go >= 1.22
BuildRequires:  zsh

%description
klog is a plain-text file format and a command line tool for time tracking.

The idea behind klog is to store data in plain-text files in a simple and
human-readable format. The notation is similar to how you would write down the
information into a physical notebook using pen and paper. Manipulating your
data is as easy as opening the file in a text editor and making changes to the
copy. By using the klog command line tool you can search, evaluate and
manipulate your data from the terminal.

%package -n %{name}-bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description -n %{name}-bash-completion
Bash command line completion support for %{name}.

%package -n %{name}-fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description -n %{name}-fish-completion
Fish command line completion support for %{name}.

%package -n %{name}-zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description -n %{name}-zsh-completion
zsh command line completion support for %{name}.

%prep
%autosetup -p 1 -a 1

%build
COMMIT_HASH="$(sed -n 's/commit: \(.*\)/\1/p' %_sourcedir/%{name}.obsinfo)"

go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags=" \
   -X main.BinaryVersion=v%{version} \
   -X main.BinaryBuildHash=${COMMIT_HASH}" \
   -o bin/%{name} ./%{name}.go

%install
# Install the binary.
install -D -m 0755 bin/%{name} %{buildroot}/%{_bindir}/%{name}

# create the bash completion file
mkdir -p %{buildroot}%{_datarootdir}/bash-completion/completions/
%{buildroot}/%{_bindir}/%{name} completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/%{name}

# create the fish completion file
mkdir -p %{buildroot}%{_datarootdir}/fish/vendor_completions.d/
%{buildroot}/%{_bindir}/%{name} completion fish > %{buildroot}%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

# create the zsh completion file
mkdir -p %{buildroot}%{_datarootdir}/zsh/site-functions/
%{buildroot}/%{_bindir}/%{name} completion zsh > %{buildroot}%{_datarootdir}/zsh/site-functions/_%{name}

%files
%doc README.md
%license LICENSE.txt
%{_bindir}/%{name}

%files -n %{name}-bash-completion
%{_datarootdir}/bash-completion/completions/%{name}

%files -n %{name}-fish-completion
%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

%files -n %{name}-zsh-completion
%{_datarootdir}/zsh/site-functions/_%{name}

%changelog
* Fri Nov 29 2024 opensuse_buildservice@ojkastl.de
- Update to version 6.5:
  * Release v6.5
  * Upgrade dependencies
  * Introduce “basic” colour theme
  * Upgrade Go version and all dependencies
  * Add “resume” flags to `klog switch`
  * Sort warn flags alphabetically
  * Fix output alignment with Unicode characters (#324)
  * Add config option to disable warnings permanently
  * Enable CI on pull requests
* Tue Jul 16 2024 opensuse_buildservice@ojkastl.de
- Update to version 6.4:
  * Release v6.4
  * Add `--create` flag for `klog bookmarks set`
  * Fix coloring of inlined totals
  * Support `--resume-nth`/`-N` flag for `klog start`
* Mon Jun 10 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- new package klog: Command line tool for time tracking in a
  human-readable, plain-text file format
